@@ -24,6 +24,7 @@ module.exports = {
             "installation/fonts",
             "installation/prompt",
             "installation/customize",
+            "installation/upgrade",
           ],
         },
       ],
@@ -71,6 +72,7 @@ module.exports = {
             "segments/cli/kubectl",
             "segments/cli/mvn",
             "segments/cli/nbgv",
+            "segments/cli/nix-shell",
             "segments/cli/npm",
             "segments/cli/nx",
             "segments/cli/pnpm",
